@@ -1,8 +1,12 @@
 package Test2::Util::Trace;
 require Test2::EventFacet::Trace;
-@ISA = ('Test2::EventFacet::Trace');
 
-our $VERSION = '1.302125';
+use warnings;
+use strict;
+
+our @ISA = ('Test2::EventFacet::Trace');
+
+our $VERSION = '1.302219';
 
 1;
 
@@ -14,7 +18,7 @@ __END__
 
 =head1 NAME
 
-Test2::Util::Trace - Legacy wrapper fro L<Test2::EventFacet::Trace>.
+Test2::Util::Trace - Legacy wrapper for L<Test2::EventFacet::Trace>.
 
 =head1 DESCRIPTION
 
@@ -24,7 +28,7 @@ L<Test2::EventFacet::Trace>.
 =head1 SOURCE
 
 The source code repository for Test2 can be found at
-F<http://github.com/Test-More/test-more/>.
+L<https://github.com/Test-More/test-more/>.
 
 =head1 MAINTAINERS
 
@@ -44,11 +48,11 @@ F<http://github.com/Test-More/test-more/>.
 
 =head1 COPYRIGHT
 
-Copyright 2018 Chad Granum E<lt>exodist@cpan.orgE<gt>.
+Copyright Chad Granum E<lt>exodist@cpan.orgE<gt>.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://dev.perl.org/licenses/>
+See L<https://dev.perl.org/licenses/>
 
 =cut
